@@ -39,9 +39,11 @@ var getBaseOptions = function(cb){
   if (process.env.JENKINS_URL || process.env.JENKINS_HOME){
     options.service_name = 'jenkins';
     options.service_job_id = process.env.BUILD_ID;
-    options.service_pull_request = process.env.ghprbPullId;
+    options.service_pull_request = process.env.CHANGE_ID || process.env.ghprbPullId;
+    git_committer_name = process.env.CHANGE_AUTHOR;
+    git_committer_email = process.env.CHANGE_AUTHOR_EMAIL;
     git_commit = process.env.GIT_COMMIT;
-    git_branch = process.env.GIT_BRANCH || process.env.BRANCH_NAME;
+    git_branch = process.env.CHANGE_BRANCH || process.env.GIT_BRANCH || process.env.BRANCH_NAME;
   }
 
   if (process.env.CIRCLECI){
@@ -112,6 +114,14 @@ var getBaseOptions = function(cb){
     git_branch = process.env.BRANCH_NAME;
   }
 
+  if(process.env.TF_BUILD){
+    options.service_name = 'Azure Pipelines';
+    options.service_job_id = process.env.BUILD_BUILDID;
+    options.service_pull_request = process.env.SYSTEM_PULLREQUEST_PULLREQUESTNUMBER;
+    git_commit = process.env.BUILD_SOURCEVERSION;
+    git_branch = process.env.BUILD_SOURCEBRANCHNAME;
+  }
+
   options.run_at = process.env.COVERALLS_RUN_AT || JSON.stringify(new Date()).slice(1, -1);
   if (process.env.COVERALLS_SERVICE_NAME){
     options.service_name = process.env.COVERALLS_SERVICE_NAME;
